# ShellOracle 

### Usage

More streamlined installation and platforms coming soon so ⭐ and 👀️ to stay in the loop.

Currently, ShellOracle only supports zsh on macOS. The installation process is not productized yet, so here are the
general steps to get it up and running.

1. Install [Ollama](https://ollama.ai/)
2. Source the zsh configuration
   ```zsh
   source shell/shelloracle.zsh
   ```
3. Use ctrl+f to open the prompt
